-- Mentioned in the TODO file is that I want to do away with the ugly
-- unique column names and use plain words instead. Also mentioned is
-- the desire to improve the Transport and Alias tables. This is the
-- result: what the new schema should be. It surprised me!
--
PRAGMA foreign_keys=ON;
BEGIN TRANSACTION;
--
CREATE TABLE "Transport" (key INTEGER PRIMARY KEY,
	active INTEGER DEFAULT 1, transport TEXT, nexthop INTEGER,
	mx INTEGER DEFAULT 1, port INTEGER,
	UNIQUE (transport,nexthop,mx,port));
-- Transport.nexthop would be a pointer to Domain.key, but without a
-- foreign key constraint, because it can be NULL, and the Domain table
-- has yet to be created at this point anyway.
--
CREATE TABLE "RClass" (key INTEGER PRIMARY KEY,
	name TEXT NOT NULL, UNIQUE(name));
--
CREATE TABLE "Domain" (key INTEGER PRIMARY KEY, name TEXT NOT NULL,
	active INTEGER DEFAULT 1, class INTEGER DEFAULT 0,
	sysuser INTEGER DEFAULT 0, transport INTEGER,
	rclass INTEGER DEFAULT 30, UNIQUE (name),
	FOREIGN KEY(transport) REFERENCES Transport(key)
	FOREIGN KEY(rclass) REFERENCES RClass(key));
--
CREATE TABLE "Address" (key INTEGER PRIMARY KEY,
	localpart TEXT NOT NULL, domain INTEGER NOT NULL,
	active INTEGER DEFAULT 1, transport INTEGER, rclass INTEGER,
	FOREIGN KEY(domain) REFERENCES Domain(key),
	FOREIGN KEY(transport) REFERENCES Transport(key),
	FOREIGN KEY(rclass) REFERENCES RClass(key),
	UNIQUE (localpart, domain));
--
CREATE TABLE "Alias" (key INTEGER PRIMARY KEY,
	name INTEGER NOT NULL, active INTEGER DEFAULT 1,
	target TEXT NOT NULL, exten TEXT,
	FOREIGN KEY(name) REFERENCES Address(key)
	FOREIGN KEY(target) REFERENCES Address(key));
-- Along with that new foreign key constraint, we have to add a special
-- "null" record to the Address table. If Alias.target=0, that tells us
-- that the Alias.exten field contains a /file/name, or a |command, or
-- an :include:/file/name. Otherwise, Alias.exten is the same as was in
-- the VAlias table, below. WAS, because now that the definition is the
-- same, we can eliminate VAlias! Alias.active as another tri-state
-- field can differentiate local(8) aliases(5) from virtual(5).
--
CREATE TABLE "VMailbox" (key INTEGER PRIMARY KEY,
	active INTEGER DEFAULT 1, password TEXT, home TEXT,
	uid INTEGER, gid INTEGER,
	FOREIGN KEY(key) REFERENCES Address(key));
--
CREATE TABLE "BScat" (key INTEGER PRIMARY KEY,
	sender TEXT NOT NULL, priority INTEGER,
	target TEXT NOT NULL, UNIQUE (sender, priority));
--
COMMIT;
-- Simplification ... ain't it beautiful?
